Welcome to pwman3’s documentation! — pwman3 0.6 documentation

### Navigation

- index
- modules |
- next |
- pwman3 0.6 documentation »

# Welcome to pwman3’s documentation!

Contents:

- installing and upgrading:
  - Upgrading from version 0.5.x
  - A Note about Python versions
- Pwman3 - tutorial
- Configuring Pwman3

## About pwman3:

Pwman3 is a simple command line password manager for Python 2.7-3.X.

### Navigation

- index
- modules |
- next |
- pwman3 0.6 documentation »